==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/gl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "Add external admin" : "Engadir administrador externo",
    "Your files are not protected by encryption." : "Os seus ficheiros non están protexidos con cifrado.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Os seus ficheiros están protexidos con {linkopen}cifrado no lado do servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protexido con cifrado de disco completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Os seus ficheiros están cifrados con {linkopen}cifrado no lado do servidor ↗{linkclose}. Ademais, este servidor está protexido con cifrado de disco completo.",
    "This server is using full-disk-encryption." : "Este servidor está a usar o cifrado de disco completo.",
    "Your data is located in: " : "Os seus datos están localizados en:",
    "The admin hasn't selected the location of the server yet." : "O administrador aínda non seleccionou a localización do servidor.",
    "Please select a country" : "Seleccione un país",
    "You don't have any shares with individual users." : "Non tes ningunha compartición con usuarios individuais.",
    "Somaliland" : "Somalia",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Acerbaixán",
    "Bosnia and Herzegowina" : "Bosnia e Hercegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "Congo (República democrática do)",
    "Central African Republic" : "República Centro Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíza",
    "Cote d'Ivoire" : "Costa do Marfin",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemania",
    "Djibouti" : "Xibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Alxeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exipto",
    "West Sahara" : "Sáhara Ocidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fidxi",
    "Falkland Islands" : "Illas Malvinas (Falkland)",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Xeorxia",
    "Ghana" : "Ghana",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bisau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Quenia",
    "Kyrgyzstan" : "Quirguistán",
    "Cambodia" : "Camboxa",
    "North Korea" : "Corea do Norte",
    "South Korea" : "Corea do Sur",
    "Kuwait" : "Kuvait",
    "Kazakhstan" : "Cazaquistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Malí",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nova Caledonia",
    "Niger" : "Níxer",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Celandia",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "Papua New Guinea" : "Papúa Nova Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistán",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Romania" : "Romanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomón",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Slovenia" : "Eslovenia",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Serra Leoa",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudán do Sur",
    "El Salvador" : "O Salvador",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Terras Austrais e Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Timor-Leste" : "Timor do Leste",
    "Turkmenistan" : "Turquemenistán",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trindade e Tobago",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos (de N A)",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Usbequistán",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iemen",
    "South Africa" : "Suráfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Cimbabue",
    "Your Nextcloud account" : "A súa conta de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Os seus datos representan quen é e é doado abusar deles. En Nextcloud cremos que ten dereito a decidir o que ocorre cos seus datos. Nextcloud protexe os seus dereitos tal e como se define no Manifiesto de datos do usuario.",
    "User Data Manifesto 2.0" : "Manifesto de datos do usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo dereitos básicos para que as persoas controlen os seus propios datos na era da Internet",
    "Control" : "Control",
    "over user data access" : "sobre o acceso aos datos do usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os datos enviados de forma explícita e voluntaria por un usuario deben estar baixo o control final do usuario. Os usuarios deben poder decidir a quen conceder acceso directo aos seus datos e con que permisos e licenzas se debe conceder ese acceso.",
    "Knowledge" : "Coñecemento",
    "of how the data is stored" : "de como se almacenan os datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cando os datos se envían a un provedor de servizos específico, os usuarios deben estar informados sobre o lugar onde o provedor de servizos específico almacena os datos, por canto tempo, en que xurisdición opera o provedor de servizos específico e cales son as leis aplicábeis.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escoller unha plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuarios sempre poderán extraer os seus datos do servizo en calquera momento sen experimentar ningún bloqueo de provedor. É necesario garantir estándares abertos para formatos e protocolos.",
    "Learn more ↗" : "Aprender máis ↗",
    "Where is your data?" : "Onde están os seus datos?",
    "Who has access to your data?" : "Quen ten acceso aos seus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Persoas coas que compartiu",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Lea a política de privacidade.",
    "Encryption" : "Cifrado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/gl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidade",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade amósalle onde están almacenados os seus datos e quen pode acceder a eles, ben porque compartiu con eles ou porque son administradores.",
    "Add external admin" : "Engadir administrador externo",
    "Your files are not protected by encryption." : "Os seus ficheiros non están protexidos con cifrado.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Os seus ficheiros están protexidos con {linkopen}cifrado no lado do servidor ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protexido con cifrado de disco completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Os seus ficheiros están cifrados con {linkopen}cifrado no lado do servidor ↗{linkclose}. Ademais, este servidor está protexido con cifrado de disco completo.",
    "This server is using full-disk-encryption." : "Este servidor está a usar o cifrado de disco completo.",
    "Your data is located in: " : "Os seus datos están localizados en:",
    "The admin hasn't selected the location of the server yet." : "O administrador aínda non seleccionou a localización do servidor.",
    "Please select a country" : "Seleccione un país",
    "You don't have any shares with individual users." : "Non tes ningunha compartición con usuarios individuais.",
    "Somaliland" : "Somalia",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Acerbaixán",
    "Bosnia and Herzegowina" : "Bosnia e Hercegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélxica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Brunei" : "Brunei",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "Congo (República democrática do)",
    "Central African Republic" : "República Centro Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suíza",
    "Cote d'Ivoire" : "Costa do Marfin",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemania",
    "Djibouti" : "Xibuti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Alxeria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Exipto",
    "West Sahara" : "Sáhara Ocidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fidxi",
    "Falkland Islands" : "Illas Malvinas (Falkland)",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Xeorxia",
    "Ghana" : "Ghana",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea-Bisau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Xamaica",
    "Jordan" : "Xordania",
    "Japan" : "Xapón",
    "Kenya" : "Quenia",
    "Kyrgyzstan" : "Quirguistán",
    "Cambodia" : "Camboxa",
    "North Korea" : "Corea do Norte",
    "South Korea" : "Corea do Sur",
    "Kuwait" : "Kuvait",
    "Kazakhstan" : "Cazaquistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Malí",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nova Caledonia",
    "Niger" : "Níxer",
    "Nigeria" : "Nixeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Baixos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Celandia",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "Papua New Guinea" : "Papúa Nova Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistán",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Catar",
    "Romania" : "Romanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudita",
    "Solomon Islands" : "Illas Salomón",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Slovenia" : "Eslovenia",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Serra Leoa",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Suriname",
    "South Sudan" : "Sudán do Sur",
    "El Salvador" : "O Salvador",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Terras Austrais e Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Taxiquistán",
    "Timor-Leste" : "Timor do Leste",
    "Turkmenistan" : "Turquemenistán",
    "Tunisia" : "Tunisia",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trindade e Tobago",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucraína",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos (de N A)",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Usbequistán",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Iemen",
    "South Africa" : "Suráfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Cimbabue",
    "Your Nextcloud account" : "A súa conta de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Os seus datos representan quen é e é doado abusar deles. En Nextcloud cremos que ten dereito a decidir o que ocorre cos seus datos. Nextcloud protexe os seus dereitos tal e como se define no Manifiesto de datos do usuario.",
    "User Data Manifesto 2.0" : "Manifesto de datos do usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definindo dereitos básicos para que as persoas controlen os seus propios datos na era da Internet",
    "Control" : "Control",
    "over user data access" : "sobre o acceso aos datos do usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os datos enviados de forma explícita e voluntaria por un usuario deben estar baixo o control final do usuario. Os usuarios deben poder decidir a quen conceder acceso directo aos seus datos e con que permisos e licenzas se debe conceder ese acceso.",
    "Knowledge" : "Coñecemento",
    "of how the data is stored" : "de como se almacenan os datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cando os datos se envían a un provedor de servizos específico, os usuarios deben estar informados sobre o lugar onde o provedor de servizos específico almacena os datos, por canto tempo, en que xurisdición opera o provedor de servizos específico e cales son as leis aplicábeis.",
    "Freedom" : "Liberdade",
    "to choose a platform" : "para escoller unha plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuarios sempre poderán extraer os seus datos do servizo en calquera momento sen experimentar ningún bloqueo de provedor. É necesario garantir estándares abertos para formatos e protocolos.",
    "Learn more ↗" : "Aprender máis ↗",
    "Where is your data?" : "Onde están os seus datos?",
    "Who has access to your data?" : "Quen ten acceso aos seus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Persoas coas que compartiu",
    "Privacy policy" : "Política de privacidade",
    "Read the privacy policy." : "Lea a política de privacidade.",
    "Encryption" : "Cifrado"
},
"nplurals=2; plural=(n != 1);");
